[Returnanalytics-commits] r2937 - in pkg/PortfolioAnalytics: . R man

noreply at r-forge.r-project.org noreply at r-forge.r-project.org
Fri Aug 30 05:44:48 CEST 2013


Author: rossbennett34
Date: 2013-08-30 05:44:48 +0200 (Fri, 30 Aug 2013)
New Revision: 2937

Modified:
   pkg/PortfolioAnalytics/DESCRIPTION
   pkg/PortfolioAnalytics/R/constraints.R
   pkg/PortfolioAnalytics/R/generics.R
   pkg/PortfolioAnalytics/man/box_constraint.Rd
   pkg/PortfolioAnalytics/man/constraint.Rd
   pkg/PortfolioAnalytics/man/factor_exposure_constraint.Rd
   pkg/PortfolioAnalytics/man/group_constraint.Rd
Log:
Changing 'seed' to 'initial' where appropriat in generic methods and constraints.

Modified: pkg/PortfolioAnalytics/DESCRIPTION
===================================================================
--- pkg/PortfolioAnalytics/DESCRIPTION	2013-08-30 03:23:27 UTC (rev 2936)
+++ pkg/PortfolioAnalytics/DESCRIPTION	2013-08-30 03:44:48 UTC (rev 2937)
@@ -53,3 +53,4 @@
     'chart.Weights.R'
     'chart.RiskReward.R'
     'charts.efficient.frontier.R'
+    'charts.risk.R'

Modified: pkg/PortfolioAnalytics/R/constraints.R
===================================================================
--- pkg/PortfolioAnalytics/man/box_constraint.Rd	2013-08-30 03:23:27 UTC (rev 2936)
+++ pkg/PortfolioAnalytics/man/box_constraint.Rd	2013-08-30 03:44:48 UTC (rev 2937)
@@ -9,7 +9,7 @@
   \item{type}{character type of the constraint}
 
   \item{assets}{number of assets, or optionally a named
-  vector of assets specifying seed weights}
+  vector of assets specifying initial weights}
 
   \item{min}{numeric or named vector specifying minimum
   weight box constraints}
@@ -18,11 +18,11 @@
   weight box constraints}
 
   \item{min_mult}{numeric or named vector specifying
-  minimum multiplier box constraint from seed weight in
+  minimum multiplier box constraint from initial weight in
   \code{assets}}
 
   \item{max_mult}{numeric or named vector specifying
-  maximum multiplier box constraint from seed weight in
+  maximum multiplier box constraint from initial weight in
   \code{assets}}
 
   \item{enabled}{TRUE/FALSE}

Modified: pkg/PortfolioAnalytics/man/constraint.Rd
===================================================================
--- pkg/PortfolioAnalytics/man/constraint.Rd	2013-08-30 03:23:27 UTC (rev 2936)
+++ pkg/PortfolioAnalytics/man/constraint.Rd	2013-08-30 03:44:48 UTC (rev 2937)
@@ -13,7 +13,7 @@
 }
 \arguments{
   \item{assets}{number of assets, or optionally a named
-  vector of assets specifying seed weights}
+  vector of assets specifying initial weights}
 
   \item{...}{any other passthru parameters}
 
@@ -24,11 +24,11 @@
   weight box constraints}
 
   \item{min_mult}{numeric or named vector specifying
-  minimum multiplier box constraint from seed weight in
+  minimum multiplier box constraint from initial weight in
   \code{assets}}
 
   \item{max_mult}{numeric or named vector specifying
-  maximum multiplier box constraint from seed weight in
+  maximum multiplier box constraint from initial weight in
   \code{assets}}
 
   \item{min_sum}{minimum sum of all asset weights, default
@@ -44,7 +44,7 @@
   update}
 
   \item{assets}{number of assets, or optionally a named
-  vector of assets specifying seed weights}
+  vector of assets specifying initial weights}
 
   \item{...}{any other passthru parameters}
 

Modified: pkg/PortfolioAnalytics/man/factor_exposure_constraint.Rd
===================================================================
--- pkg/PortfolioAnalytics/man/factor_exposure_constraint.Rd	2013-08-30 03:23:27 UTC (rev 2936)
+++ pkg/PortfolioAnalytics/man/factor_exposure_constraint.Rd	2013-08-30 03:44:48 UTC (rev 2937)
@@ -9,7 +9,7 @@
 \arguments{
   \item{type}{character type of the constraint}
 
-  \item{assets}{named vector of assets specifying seed
+  \item{assets}{named vector of assets specifying initial
   weights}
 
   \item{B}{vector or matrix of risk factor exposures}

Modified: pkg/PortfolioAnalytics/man/group_constraint.Rd
===================================================================
--- pkg/PortfolioAnalytics/man/group_constraint.Rd	2013-08-30 03:23:27 UTC (rev 2936)
+++ pkg/PortfolioAnalytics/man/group_constraint.Rd	2013-08-30 03:44:48 UTC (rev 2937)
@@ -10,7 +10,7 @@
   \item{type}{character type of the constraint}
 
   \item{assets}{number of assets, or optionally a named
-  vector of assets specifying seed weights}
+  vector of assets specifying initial weights}
 
   \item{groups}{vector specifying the groups of the assets}
 



More information about the Returnanalytics-commits mailing list
--- pkg/PortfolioAnalytics/R/constraints.R	2013-08-30 03:23:27 UTC (rev 2936)
+++ pkg/PortfolioAnalytics/R/constraints.R	2013-08-30 03:44:48 UTC (rev 2937)
@@ -17,17 +17,17 @@
 #' 
 #' See main documentation in \code{\link{add.constraint}}
 #' 
 #' @param assets number of assets, or optionally a named vector of assets specifying seed weights
 #' @param ... any other passthru parameters
 #' @param min numeric or named vector specifying minimum weight box constraints
 #' @param max numeric or named vector specifying minimum weight box constraints
-#' @param min_mult numeric or named vector specifying minimum multiplier box constraint from seed weight in \code{assets}
-#' @param max_mult numeric or named vector specifying maximum multiplier box constraint from seed weight in \code{assets}
+#' @param min_mult numeric or named vector specifying minimum multiplier box constraint from initial weight in \code{assets}
+#' @param max_mult numeric or named vector specifying maximum multiplier box constraint from initial weight in \code{assets}
 #' @param min_sum minimum sum of all asset weights, default .99
 #' @param max_sum maximum sum of all asset weights, default 1.01
 #' @param weight_seq seed sequence of weights, see \code{\link{generatesequence}}
 #' @param type character type of the constraint to add or update
 #' @param assets number of assets, or optionally a named vector of assets specifying seed weights
 #' @param ... any other passthru parameters
 #' @param constrclass character to name the constraint class
 #' @author Peter Carl, Brian G. Peterson, Ross Bennett
@@ -50,7 +50,7 @@
       if (length(assets) == 1) {
         nassets=assets
         #we passed in a number of assets, so we need to create the vector
-        message("assuming equal weighted seed portfolio")
+        message("assuming equal weighted initial portfolio")
         assets<-rep(1/nassets,nassets)
       } else {
         nassets = length(assets)
@@ -65,7 +65,7 @@
     if(is.character(assets)){
       nassets=length(assets)
       assetnames=assets
-      message("assuming equal weighted seed portfolio")
+      message("assuming equal weighted initial portfolio")
       assets<-rep(1/nassets,nassets)
       names(assets)<-assetnames  # set names, so that other code can access it,
       # and doesn't have to know about the character vector
@@ -132,7 +132,7 @@
       max_mult = NULL
     }
   }
   ##now adjust min and max to account for min_mult and max_mult from seed
   if(!is.null(min_mult) & !is.null(min)) {
     tmp_min <- assets*min_mult
     #TODO FIXME this creates a list, and it should create a named vector or matrix
@@ -364,11 +364,11 @@
 #' This function is called by add.constraint when type="box" is specified. see \code{\link{add.constraint}}
 #'
 #' @param type character type of the constraint
 #' @param assets number of assets, or optionally a named vector of assets specifying seed weights
 #' @param min numeric or named vector specifying minimum weight box constraints
 #' @param max numeric or named vector specifying minimum weight box constraints
-#' @param min_mult numeric or named vector specifying minimum multiplier box constraint from seed weight in \code{assets}
-#' @param max_mult numeric or named vector specifying maximum multiplier box constraint from seed weight in \code{assets}
+#' @param min_mult numeric or named vector specifying minimum multiplier box constraint from initial weight in \code{assets}
+#' @param max_mult numeric or named vector specifying maximum multiplier box constraint from initial weight in \code{assets}
 #' @param enabled TRUE/FALSE
 #' @param message TRUE/FALSE. The default is message=FALSE. Display messages if TRUE.
 #' @param \dots any other passthru parameters to specify box constraints
@@ -461,7 +461,7 @@
     }
   }
   
   # now adjust min and max to account for min_mult and max_mult from seed
   if(!is.null(min_mult) & !is.null(min)) {
     tmp_min <- assets * min_mult
     #TODO FIXME this creates a list, and it should create a named vector or matrix
@@ -485,7 +485,7 @@
 #' This function is called by add.constraint when type="group" is specified. see \code{\link{add.constraint}}
 #'
 #' @param type character type of the constraint
 #' @param assets number of assets, or optionally a named vector of assets specifying seed weights
 #' @param groups vector specifying the groups of the assets
 #' @param group_labels character vector to label the groups (e.g. size, asset class, style, etc.)
 #' @param group_min numeric or vector specifying minimum weight group constraints
@@ -916,7 +916,7 @@
 #' \code{B} matrix without column names or row names.
 #' 
 #' @param type character type of the constraint
 #' @param assets named vector of assets specifying seed weights
 #' @param B vector or matrix of risk factor exposures
 #' @param lower vector of lower bounds of constraints for risk factor exposures
 #' @param upper vector of upper bounds of constraints for risk factor exposures
@@ -17,17 +17,17 @@
 #' See main documentation in \code{\link{add.constraint}}
 #' 
-#' @param assets number of assets, or optionally a named vector of assets specifying seed weights
+#' @param assets number of assets, or optionally a named vector of assets specifying initial weights
 #' @param ... any other passthru parameters
 #' @param min numeric or named vector specifying minimum weight box constraints
@@ -17,17 +17,17 @@
 #' @param weight_seq seed sequence of weights, see \code{\link{generatesequence}}
 #' @param type character type of the constraint to add or update
-#' @param assets number of assets, or optionally a named vector of assets specifying seed weights
+#' @param assets number of assets, or optionally a named vector of assets specifying initial weights
 #' @param ... any other passthru parameters
 #' @param constrclass character to name the constraint class
@@ -132,7 +132,7 @@
     }
   }
-  ##now adjust min and max to account for min_mult and max_mult from seed
+  ##now adjust min and max to account for min_mult and max_mult from initial
   if(!is.null(min_mult) & !is.null(min)) {
     tmp_min <- assets*min_mult
@@ -364,11 +364,11 @@
 #'
 #' @param type character type of the constraint
-#' @param assets number of assets, or optionally a named vector of assets specifying seed weights
+#' @param assets number of assets, or optionally a named vector of assets specifying initial weights
 #' @param min numeric or named vector specifying minimum weight box constraints
 #' @param max numeric or named vector specifying minimum weight box constraints
@@ -461,7 +461,7 @@
   }
   
-  # now adjust min and max to account for min_mult and max_mult from seed
+  # now adjust min and max to account for min_mult and max_mult from initial
   if(!is.null(min_mult) & !is.null(min)) {
     tmp_min <- assets * min_mult
@@ -485,7 +485,7 @@
 #'
 #' @param type character type of the constraint
-#' @param assets number of assets, or optionally a named vector of assets specifying seed weights
+#' @param assets number of assets, or optionally a named vector of assets specifying initial weights
 #' @param groups vector specifying the groups of the assets
 #' @param group_labels character vector to label the groups (e.g. size, asset class, style, etc.)
@@ -916,7 +916,7 @@
 #' 
 #' @param type character type of the constraint
-#' @param assets named vector of assets specifying seed weights
+#' @param assets named vector of assets specifying initial weights
 #' @param B vector or matrix of risk factor exposures
 #' @param lower vector of lower bounds of constraints for risk factor exposures

Modified: pkg/PortfolioAnalytics/R/generics.R
===================================================================
--- pkg/PortfolioAnalytics/R/generics.R	2013-08-30 03:23:27 UTC (rev 2936)
+++ pkg/PortfolioAnalytics/R/generics.R	2013-08-30 03:44:48 UTC (rev 2937)
@@ -181,7 +181,7 @@
   cat("PortfolioAnalytics Portfolio Specification Summary", "\n")
   cat(rep("*", 50) ,"\n", sep="")
   
-  cat("Assets and Seed Weights:\n")
+  cat("Assets and Initial Weights:\n")
   print(object$assets)
   cat("\n")
   
@@ -492,8 +492,8 @@
   }
   cat("\n")
   
-  # get seed portfolio
-  cat("Portfolio Assets and Seed Weights:\n")
+  # get initial portfolio
+  cat("Portfolio Assets and Initial Weights:\n")
   print.default(object$portfolio$assets)
   cat("\n")
   
@@ -596,7 +596,7 @@
   cat("Turnover Target Constraint:\n")
   print(constraints$turnover_target)
   cat("\n")
-  cat("Realized turnover from seed weights:\n")
+  cat("Realized turnover from initial weights:\n")
   print(turnover(object$weights, wts.init=object$portfolio$assets))
   cat("\n")
   

Modified: pkg/PortfolioAnalytics/man/box_constraint.Rd
===================================================================